from setuptools import setup

setup(name='zoey_distributions',
      version='0.1',
      description='Gaussian distributions and Binomial distributions',
      packages=['zoey_distributions'],
      author = 'Jadesola Adedokun',
      author_email = 'jadesolaadedokun@gmail.com',
      zip_safe=False)
